@@ -30,4 +30,6 @@ def django_settings_is_configured():
 
 
 def get_django_version():
-    return __import__("django").VERSION
+    import django
+
+    return django.VERSION
