@@ -52,6 +52,7 @@ _report_header = []
 # ############### pytest hooks ################
 
 
+@pytest.hookimpl()
 def pytest_addoption(parser):
     group = parser.getgroup("django")
     group.addoption(
@@ -241,6 +242,7 @@ def _get_boolean_value(x, name, default=None):
         )
 
 
+@pytest.hookimpl()
 def pytest_load_initial_conftests(early_config, parser, args):
     # Register the marks
     early_config.addinivalue_line(
@@ -322,6 +324,7 @@ def pytest_load_initial_conftests(early_config, parser, args):
     _setup_django()
 
 
+@pytest.hookimpl()
 def pytest_report_header():
     if _report_header:
         return ["django: " + ", ".join(_report_header)]
@@ -369,7 +372,7 @@ def pytest_collection_modifyitems(items):
 
         return 2
 
-    items[:] = sorted(items, key=get_order_number)
+    items.sort(key=get_order_number)
 
 
 @pytest.fixture(autouse=True, scope="session")
@@ -513,7 +516,7 @@ def _django_set_urlconf(request):
         def restore():
             django.conf.settings.ROOT_URLCONF = original_urlconf
             # Copy the pattern from
-            # https://github.com/django/django/blob/master/django/test/signals.py#L152
+            # https://github.com/django/django/blob/main/django/test/signals.py#L152
             clear_url_caches()
             set_urlconf(None)
 
